@@ -83,16 +83,19 @@ class ExecutableDirectedMultiGraph(nx.MultiDiGraph):
         execution_order = self.get_execution_order(self)
 
         print("The node functions will be executed in the following order: \n")
-        print("\n".join(execution_order))
+        print("\n".join(str(x) for x in execution_order))
 
         print("Simulating the function calls:")
         for node in execution_order:
             function_arguments = self.nodes[node].get("function_arguments", [])
-            function_name = self.nodes[node].get("function").__name__
+            try:
+                function_name = self.nodes[node].get("function").__name__
+            except AttributeError:
+                function_name = "anonymous"
 
             message = f"Calling function {function_name} "
             if len(function_arguments) > 0:
-                message += f"with arguments {', '.join(function_arguments)}"
+                message += f"with arguments {', '.join(str(x) for x in function_arguments)}"
             print(message)
 
     def display_graph(self):
